MyResponsive class

Constructors

MyResponsive(BuildContext context, {double designWidth = 1536, double designHeight = 792})

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fontSizeByHeight(double fontSize) → double
fontSizeByWidth(double fontSize) → double
height(double value) → double
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
width(double value) → double

Operators

operator ==(Object other) → bool
The equality operator.
inherited