SearchAppBar class

Inheritance

Constructors

SearchAppBar({Key? key, required double childHeight, double? appBarHeight, Color? appBarColor, Widget? body, bool? Scroll, AlignmentGeometry? childAlignment, DecorationImage? childBackGroundimage, BoxBorder? childBorder, List<BoxShadow>? childBoxShadow, double? childCircularRadius, Color? childColor, Gradient? childGradient, EdgeInsetsGeometry? childPadding, double? childWidth, double? columnSpaces, required dynamic onSelected(int SelectedIndex), double? rowSpaces, required Widget builder(int Index), required int itemCount, Widget? FilterWidget, Widget? SortWidget, bool? SubAppBarVisible, required dynamic onTheSearch(bool isOnTheSearch, String SearchText)?, Widget? OnTheRightWidget, Icon? SearchIcon, bool? SearchIconVisible, double? barLeftPadding, double? barRightPadding, double? paddingBetweenSearchBarAndRightWidget, dynamic onValueChange(String value)?, dynamic onSearchTapped()?, Widget? OnTheLeftWidget, double? paddingBetweenSearchBarAndLeftWidget})

Properties

appBarColor ↔ Color?
getter/setter pair
appBarHeight ↔ double?
getter/setter pair
barLeftPadding ↔ double?
getter/setter pair
barRightPadding ↔ double?
getter/setter pair
body ↔ Widget?
getter/setter pair
builder ↔ Widget Function(int Index)
getter/setter pair
childAlignment ↔ AlignmentGeometry?
getter/setter pair
childBackGroundimage ↔ DecorationImage?
getter/setter pair
childBorder ↔ BoxBorder?
getter/setter pair
childBoxShadow ↔ List<BoxShadow>?
getter/setter pair
childCircularRadius ↔ double?
getter/setter pair
childColor ↔ Color?
getter/setter pair
childGradient ↔ Gradient?
getter/setter pair
childHeight ↔ double
getter/setter pair
childPadding ↔ EdgeInsetsGeometry?
getter/setter pair
childWidth ↔ double?
getter/setter pair
columnSpaces ↔ double?
getter/setter pair
FilterWidget ↔ Widget?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
itemCount ↔ int
getter/setter pair
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSearchTapped ↔ dynamic Function()?
getter/setter pair
onSelected ↔ dynamic Function(int SelectedIndex)
getter/setter pair
OnTheLeftWidget ↔ Widget?
getter/setter pair
OnTheRightWidget ↔ Widget?
getter/setter pair
onTheSearch ↔ dynamic Function(bool isOnTheSearch, String SearchText)?
getter/setter pair
onValueChange ↔ dynamic Function(String value)?
getter/setter pair
paddingBetweenSearchBarAndLeftWidget ↔ double?
getter/setter pair
paddingBetweenSearchBarAndRightWidget ↔ double?
getter/setter pair
rowSpaces ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Scroll ↔ bool?
getter/setter pair
SearchIcon ↔ Icon?
getter/setter pair
SearchIconVisible ↔ bool?
getter/setter pair
SortWidget ↔ Widget?
getter/setter pair
SubAppBarVisible ↔ bool?
getter/setter pair

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<SearchAppBar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited