MyTools/tools/App_Containing_Tools/StageIndicator library

Enums

Enum to control where the navigation bar is placed relative to the page.
StageProgressOrientation
Enum to control the orientation of the progress indicator.
TransitionType
Enum to control the type of page transition.