TBMaker class

Inheritance

Constructors

TBMaker({Key? key, required List<Widget> tabsList, required List<Widget> pagesList, dynamic onChanged(int Index)?, int? initIndex, AlignmentGeometry? tabsAlignment, DecorationImage? tabsBackGroundimage, BoxBorder? tabsBorder, List<BoxShadow>? tabsBoxShadow, double? tabsCircularRadius, Color? tabsColor, Gradient? tabsGradient, double? tabsHeight, EdgeInsetsGeometry? tabsMargin, EdgeInsetsGeometry? tabsPadding, double? tabsWidth, bool? Scrollable, EdgeInsetsGeometry? tabsRowPadding, required double? height, double? width, double? indicatorWeight, BoxDecoration? selectedTabDecoration, Color? indicatorColor})

Properties

hashCode → int
The hash code for this object.
no setterinherited
height ↔ double?
getter/setter pair
indicatorColor ↔ Color?
getter/setter pair
indicatorWeight ↔ double?
getter/setter pair
initIndex ↔ int?
getter/setter pair
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChanged ↔ dynamic Function(int Index)?
getter/setter pair
pagesList ↔ List<Widget>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
Scrollable ↔ bool?
getter/setter pair
selectedTabDecoration ↔ BoxDecoration?
getter/setter pair
tabsAlignment ↔ AlignmentGeometry?
getter/setter pair
tabsBackGroundimage ↔ DecorationImage?
getter/setter pair
tabsBorder ↔ BoxBorder?
getter/setter pair
tabsBoxShadow ↔ List<BoxShadow>?
getter/setter pair
tabsCircularRadius ↔ double?
getter/setter pair
tabsColor ↔ Color?
getter/setter pair
tabsGradient ↔ Gradient?
getter/setter pair
tabsHeight ↔ double?
getter/setter pair
tabsList ↔ List<Widget>
getter/setter pair
tabsMargin ↔ EdgeInsetsGeometry?
getter/setter pair
tabsPadding ↔ EdgeInsetsGeometry?
getter/setter pair
tabsRowPadding ↔ EdgeInsetsGeometry?
getter/setter pair
tabsWidth ↔ double?
getter/setter pair
width ↔ double?
getter/setter pair

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<TBMaker>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited