MyMiniAudioPlayer class

Inheritance

Constructors

MyMiniAudioPlayer({Key? key, String? audioSource, bool isAsset = false, File? audioFile, TimerPosition timerPosition = TimerPosition.right, TextStyle? timerTextStyle, Color? playPauseIconColor = Colors.blue, Color? sliderActiveColor = Colors.blue, Color? sliderInactiveColor = Colors.grey, Color? sliderThumbColor = Colors.blueAccent, Color? containerColor = Colors.white, double? containerCircularRadius = 12, List<BoxShadow>? containerBoxShadow, EdgeInsetsGeometry? containerPadding, EdgeInsetsGeometry? containerMargin, Alignment? containerAlignment, Gradient? containerGradient, DecorationImage? containerBackgroundImage, BoxBorder? containerBorder, double? containerHeight, double? containerWidth, Matrix4? containerTransform, Clip? containerClipBehavior, BoxShape? containerShape})
const

Properties

audioFile → File?
final
audioSource → String?
Provide either a audioSource (for asset or network URL) or an audioFile. If audioFile is provided, it takes precedence.
final
containerAlignment → Alignment?
final
containerBackgroundImage → DecorationImage?
final
containerBorder → BoxBorder?
final
containerBoxShadow → List<BoxShadow>?
final
containerCircularRadius → double?
final
containerClipBehavior → Clip?
final
containerColor → Color?
final
containerGradient → Gradient?
final
containerHeight → double?
final
containerMargin → EdgeInsetsGeometry?
final
containerPadding → EdgeInsetsGeometry?
final
containerShape → BoxShape?
final
containerTransform → Matrix4?
final
containerWidth → double?
final
hashCode → int
The hash code for this object.
no setterinherited
isAsset → bool
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
playPauseIconColor → Color?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sliderActiveColor → Color?
final
sliderInactiveColor → Color?
final
sliderThumbColor → Color?
final
timerPosition → TimerPosition
final
timerTextStyle → TextStyle?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _MyMiniAudioPlayerState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited