MyButton class

Inheritance

Constructors

MyButton({Key? key, required String text, double? textFont, FontWeight? textFontWeight, Color? textColor, Color? buttonColor, double? buttonHeight, double? buttonWidth, double? buttonCircularRadius, bool? addShadow, BoxBorder? border, Gradient? gradient, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding, void onTap()?, void onDoubleTap()?, void onHover(bool)?, void onLongPress()?, String? textFontFamily})

Properties

addShadow ↔ bool?
getter/setter pair
border ↔ BoxBorder?
getter/setter pair
buttonCircularRadius ↔ double?
getter/setter pair
buttonColor ↔ Color?
getter/setter pair
buttonHeight ↔ double?
getter/setter pair
buttonWidth ↔ double?
getter/setter pair
gradient ↔ Gradient?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin ↔ EdgeInsetsGeometry?
getter/setter pair
onDoubleTap ↔ void Function()?
getter/setter pair
onHover ↔ void Function(bool)?
getter/setter pair
onLongPress ↔ void Function()?
getter/setter pair
onTap ↔ void Function()?
getter/setter pair
padding ↔ EdgeInsetsGeometry?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text ↔ String
getter/setter pair
textColor ↔ Color?
getter/setter pair
textFont ↔ double?
getter/setter pair
textFontFamily ↔ String?
getter/setter pair
textFontWeight ↔ FontWeight?
getter/setter pair

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MyButton>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited