MyTooltip class

Inheritance

Constructors

MyTooltip({Key? key, required Widget child, required Widget tooltipContent, TooltipPositionExtended tooltipPosition = TooltipPositionExtended.bottomCenter, double tooltipDistance = 8.0, Offset additionalOffset = Offset.zero, double tooltipWidth = 200.0, double tooltipHeight = 100.0, BoxDecoration tooltipDecoration = const BoxDecoration(color: Colors.white, borderRadius: BorderRadius.all(Radius.circular(8.0)), boxShadow: [BoxShadow(color: Colors.black26, blurRadius: 8, offset: Offset(0, 4))]), EdgeInsets tooltipPadding = const EdgeInsets.all(8.0), Duration longPressDelay = const Duration(seconds: 1), Duration animationDuration = const Duration(milliseconds: 300), Duration autoHideDelay = const Duration(seconds: 3), bool showOnHover = true, bool showOnLongPress = true})
const

Properties

additionalOffset → Offset
Additional offset for fine-tuning the tooltip’s position.
final
animationDuration → Duration
Duration of the fade in/out animation.
final
autoHideDelay → Duration
Duration after which the tooltip will automatically hide. If set to Duration.zero, the tooltip stays visible until the user stops hovering or long pressing.
final
child → Widget
The widget that triggers the tooltip.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
longPressDelay → Duration
Duration after which the tooltip appears when long pressed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showOnHover → bool
Whether to show the tooltip on mouse hover.
final
showOnLongPress → bool
Whether to show the tooltip on long press.
final
tooltipContent → Widget
The content to display inside the tooltip.
final
tooltipDecoration → BoxDecoration
Decoration for the tooltip window.
final
tooltipDistance → double
Base gap between the child and the tooltip.
final
tooltipHeight → double
The height of the tooltip window.
final
tooltipPadding → EdgeInsets
Padding inside the tooltip window.
final
tooltipPosition → TooltipPositionExtended
Determines the base placement of the tooltip relative to the child.
final
tooltipWidth → double
The width of the tooltip window.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _MyTooltipState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited