MyAutoDateDisplayer class

Inheritance

Constructors

MyAutoDateDisplayer({Key? key, int daysBefore = 3, int daysAfter = 10, DateDisplayOrientation orientation = DateDisplayOrientation.horizontal, HorizontalDateOrder horizontalOrder = HorizontalDateOrder.dayNameOnTop, VerticalDateOrder verticalOrder = VerticalDateOrder.dayNameOnLeft, BoxDecoration containerDecoration = const BoxDecoration(color: Colors.transparent), EdgeInsets containerPadding = const EdgeInsets.all(8.0), EdgeInsets containerMargin = const EdgeInsets.all(0), double? containerWidth, double? containerHeight, BoxDecoration itemDecoration = const BoxDecoration(color: Colors.white, borderRadius: BorderRadius.all(Radius.circular(8.0)), border: Border.fromBorderSide(BorderSide(color: Colors.grey))), EdgeInsets itemPadding = const EdgeInsets.symmetric(vertical: 8.0, horizontal: 12.0), double? itemWidth, double? itemHeight, double itemSpacing = 8.0, TextStyle dayNameTextStyle = const TextStyle(fontSize: 16, color: Colors.black), TextStyle dayNumberTextStyle = const TextStyle(fontSize: 20, fontWeight: FontWeight.bold, color: Colors.black), bool showDayName = true, bool showDayNumber = true, Color currentDayHighlightColor = Colors.blue, required ValueChanged<DateTime> onDateSelected, ValueChanged<DateTime>? onTodayChanged, MainAxisAlignment horizontalItemMainAxisAlignment = MainAxisAlignment.spaceEvenly, CrossAxisAlignment horizontalItemCrossAxisAlignment = CrossAxisAlignment.center, MainAxisAlignment verticalItemMainAxisAlignment = MainAxisAlignment.spaceEvenly, CrossAxisAlignment verticalItemCrossAxisAlignment = CrossAxisAlignment.center, bool showSelector = false, double selectorBorderWidth = 3.0, Color selectorBorderColor = Colors.green, BorderRadius? selectorBorderRadius, ValueChanged<int>? onSelectedIndexChanged})
const

Properties

containerDecoration → BoxDecoration
Decoration for the container that holds the list view.
final
containerHeight → double?
Optional: The height of the container that holds the entire widget.
final
containerMargin → EdgeInsets
Margin for the container that holds the list view.
final
containerPadding → EdgeInsets
Padding for the container that holds the list view.
final
containerWidth → double?
Optional: The width of the container that holds the entire widget.
final
currentDayHighlightColor → Color
Highlight color for the current day.
final
dayNameTextStyle → TextStyle
Text style for the day name.
final
dayNumberTextStyle → TextStyle
Text style for the day number.
final
daysAfter → int
How many days after today to display. Defaults to 10.
final
daysBefore → int
How many days before today to display. Defaults to 3.
final
hashCode → int
The hash code for this object.
no setterinherited
horizontalItemCrossAxisAlignment → CrossAxisAlignment
When horizontal, controls the inner Column's cross axis alignment.
final
horizontalItemMainAxisAlignment → MainAxisAlignment
When horizontal, controls the inner Column's main axis alignment.
final
horizontalOrder → HorizontalDateOrder
When horizontal, order of texts.
final
itemDecoration → BoxDecoration
Decoration for each date item container.
final
itemHeight → double?
Optionally, you can set a fixed height for each date item.
final
itemPadding → EdgeInsets
Padding for each date item.
final
itemSpacing → double
Spacing between adjacent date items.
final
itemWidth → double?
Optionally, you can set a fixed width for each date item.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onDateSelected → ValueChanged<DateTime>
Callback when a date is tapped; returns the selected date.
final
onSelectedIndexChanged → ValueChanged<int>?
Callback that returns the index of the selected date.
final
onTodayChanged → ValueChanged<DateTime>?
Callback called on initialization (or when today changes) to indicate what today is.
final
orientation → DateDisplayOrientation
Overall orientation: horizontal (items scroll horizontally) or vertical (items scroll vertically).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectorBorderColor → Color
Selector border color.
final
selectorBorderRadius → BorderRadius?
Selector border radius.
final
selectorBorderWidth → double
Selector border width.
final
showDayName → bool
Whether to show the day name.
final
showDayNumber → bool
Whether to show the day number.
final
showSelector → bool
Whether to show the selector border around the selected date.
final
verticalItemCrossAxisAlignment → CrossAxisAlignment
When vertical, controls the inner Row's cross axis alignment.
final
verticalItemMainAxisAlignment → MainAxisAlignment
When vertical, controls the inner Row's main axis alignment.
final
verticalOrder → VerticalDateOrder
When vertical, order of texts.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _MyAutoDateDisplayerState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited