MyMiniOnTheRightImageViewer class

Inheritance

Constructors

MyMiniOnTheRightImageViewer({Key? key, required List images, BoxFit imageFit = BoxFit.cover, double viewportFraction = 0.8, double scaleFactor = 0.8, bool showDotsIndicator = true, double dotSize = 8.0, double dotSpacing = 4.0, Color dotColor = Colors.grey, Color activeDotColor = Colors.blue, Duration dotAnimationDuration = const Duration(milliseconds: 300), Curve dotAnimationCurve = Curves.easeInOut, bool autoScroll = false, Duration autoScrollInterval = const Duration(seconds: 3), Duration autoScrollAnimationDuration = const Duration(milliseconds: 300), Curve autoScrollCurve = Curves.easeInOut, ValueChanged<int>? onPageChanged, ValueChanged<int>? onImagePressed})
const

Properties

activeDotColor → Color
final
autoScroll → bool
final
autoScrollAnimationDuration → Duration
final
autoScrollCurve → Curve
final
autoScrollInterval → Duration
final
dotAnimationCurve → Curve
final
dotAnimationDuration → Duration
final
dotColor → Color
final
dotSize → double
final
dotSpacing → double
final
hashCode → int
The hash code for this object.
no setterinherited
imageFit → BoxFit
The BoxFit for each image.
final
images → List
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onImagePressed → ValueChanged<int>?
Called when the displayed image is tapped; provides the index.
final
onPageChanged → ValueChanged<int>?
Called when the page changes; provides the new index.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleFactor → double
The scale factor for non‑center images.
final
showDotsIndicator → bool
Whether to display the dots indicator below the carousel.
final
viewportFraction → double
The fraction of the viewport that each page occupies.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _MyMiniOnTheRightImageViewerState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited