MyColumnWidgetSelector class

Inheritance

Constructors

MyColumnWidgetSelector({Key? key, required List<Widget> iconsList, required double height, required double width, Color? barColor, Color? SelectionContainerColor, Color? unSelectedContainerColor, double? SelectionContainerHeight, double? unSelectedContainerHeight, double? SelectionContainerWidth, double? unSelectedContainerWidth, EdgeInsetsGeometry? SelectionContainerPadding, EdgeInsetsGeometry? unSelectedContainerPadding, BoxBorder? SelectionContainerBorder, BoxBorder? unSelectedContainerBorder, double? SelectionContainerCircularRadius, double? unSelectedContainerCircularRadius, Gradient? SelectionContainerGradient, Gradient? unSelectedContainerGradient, Duration? SelectionContainerAnimationDuration, EdgeInsetsGeometry? SelectionContainerMargin, EdgeInsetsGeometry? unSelectedContainerMargin, List<BoxShadow>? BarShadow, BoxBorder? BarBorder, BorderRadiusGeometry? BarborderRadius, Gradient? BarGradient, required dynamic onChange(int? index), Duration? ScrollDuration, double? BetweenSpaces, bool? reverseDirection})

Properties

BarBorder ↔ BoxBorder?
getter/setter pair
BarborderRadius ↔ BorderRadiusGeometry?
getter/setter pair
barColor ↔ Color?
getter/setter pair
BarGradient ↔ Gradient?
getter/setter pair
BarShadow ↔ List<BoxShadow>?
getter/setter pair
BetweenSpaces ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double
getter/setter pair
iconsList ↔ List<Widget>
getter/setter pair
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChange ↔ dynamic Function(int? index)
getter/setter pair
reverseDirection ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ScrollDuration ↔ Duration?
getter/setter pair
SelectionContainerAnimationDuration → Duration?
final
SelectionContainerBorder → BoxBorder?
final
SelectionContainerCircularRadius → double?
final
SelectionContainerColor → Color?
final
SelectionContainerGradient → Gradient?
final
SelectionContainerHeight → double?
final
SelectionContainerMargin → EdgeInsetsGeometry?
final
SelectionContainerPadding → EdgeInsetsGeometry?
final
SelectionContainerWidth → double?
final
unSelectedContainerBorder → BoxBorder?
final
unSelectedContainerCircularRadius → double?
final
unSelectedContainerColor → Color?
final
unSelectedContainerGradient → Gradient?
final
unSelectedContainerHeight → double?
final
unSelectedContainerMargin → EdgeInsetsGeometry?
final
unSelectedContainerPadding → EdgeInsetsGeometry?
final
unSelectedContainerWidth → double?
final
width ↔ double
getter/setter pair

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MyColumnWidgetSelector>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited