MyExpandingRowWidgetSelector class

Inheritance

Constructors

MyExpandingRowWidgetSelector({Key? key, required List<Widget> iconsList, required double height, Color? barColor, Color? SelectionContainerColor, Color? unSelectedContainerColor, double? SelectionContainerHeight, double? unSelectedContainerHeight, double? SelectionContainerWidth, double? unSelectedContainerWidth, EdgeInsetsGeometry? SelectionContainerPadding, EdgeInsetsGeometry? unSelectedContainerPadding, List<BoxShadow>? BarShadow, BoxBorder? BarBorder, double? BarCircularRadius, Gradient? BarGradient, BoxBorder? SelectionContainerBorder, BoxBorder? unSelectedContainerBorder, double? SelectionContainerCircularRadius, double? unSelectedContainerCircularRadius, Gradient? SelectionContainerGradient, Gradient? unSelectedContainerGradient, required dynamic onChange(int? index), Duration? ScrollDuration, Duration? SelectionContainerAnimationDuration, double? betweenSpaces, bool? reverseDirection, EdgeInsetsGeometry? SelectionContainerMargin, EdgeInsetsGeometry? unSelectedContainerMargin})
const

Properties

BarBorder → BoxBorder?
final
BarCircularRadius → double?
final
barColor → Color?
final
BarGradient → Gradient?
final
BarShadow → List<BoxShadow>?
final
betweenSpaces → double?
final
hashCode → int
The hash code for this object.
no setterinherited
height → double
final
iconsList → List<Widget>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onChange → dynamic Function(int? index)
final
reverseDirection → bool?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ScrollDuration → Duration?
final
SelectionContainerAnimationDuration → Duration?
final
SelectionContainerBorder → BoxBorder?
final
SelectionContainerCircularRadius → double?
final
SelectionContainerColor → Color?
final
SelectionContainerGradient → Gradient?
final
SelectionContainerHeight → double?
final
SelectionContainerMargin → EdgeInsetsGeometry?
final
SelectionContainerPadding → EdgeInsetsGeometry?
final
SelectionContainerWidth → double?
final
unSelectedContainerBorder → BoxBorder?
final
unSelectedContainerCircularRadius → double?
final
unSelectedContainerColor → Color?
final
unSelectedContainerGradient → Gradient?
final
unSelectedContainerHeight → double?
final
unSelectedContainerMargin → EdgeInsetsGeometry?
final
unSelectedContainerPadding → EdgeInsetsGeometry?
final
unSelectedContainerWidth → double?
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MyExpandingRowWidgetSelector>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited