MySwitch class

Inheritance

Constructors

MySwitch({Key? key, double? SwitchHeight, double? SwitchWidth, Color? BackLayerColorOn, required Color? BackLayerColorOff, required Color? BallColorOff, required Color? BallColorOn, Icon? OffIconBall, Icon? ONIconBall, double? SwitchHeight2, double? SwitchWidth2, Color? colorcmaker2, dynamic onChange(bool value)?, Widget? child})

Properties

BackLayerColorOff ↔ Color?
getter/setter pair
BackLayerColorOn ↔ Color?
getter/setter pair
BallColorOff ↔ Color?
getter/setter pair
BallColorOn ↔ Color?
getter/setter pair
child ↔ Widget?
getter/setter pair
colorcmaker2 ↔ Color?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
OffIconBall ↔ Icon?
getter/setter pair
onChange ↔ dynamic Function(bool value)?
getter/setter pair
ONIconBall ↔ Icon?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
SwitchHeight ↔ double?
getter/setter pair
SwitchHeight2 ↔ double?
getter/setter pair
SwitchWidth ↔ double?
getter/setter pair
SwitchWidth2 ↔ double?
getter/setter pair

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MySwitch>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited