CountdownTime class

A data class that holds the full breakdown of remaining time.

Constructors

CountdownTime({required int years, required int months, required int weeks, required int days, required int hours, required int minutes, required int seconds})

Properties

days → int
final
hashCode → int
The hash code for this object.
no setterinherited
hours → int
final
minutes → int
final
months → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seconds → int
final
weeks → int
final
years → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited