TimeFlipEvent class

The object returned by each flip callback.

Constructors

TimeFlipEvent({required int hour, required int minute, required int second, String? period})

Properties

hashCode → int
The hash code for this object.
no setterinherited
hour → int
final
minute → int
final
period → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
second → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited