MyMiniOnTheRightCardViewer class

Inheritance

Constructors

MyMiniOnTheRightCardViewer({Key? key, required int itemCount, required Widget builder(BuildContext context, int index), double viewportFraction = 0.8, double scaleFactor = 0.8, bool showDotsIndicator = true, double dotSize = 8.0, double dotSpacing = 4.0, Color dotColor = Colors.grey, Color activeDotColor = Colors.blue, Duration dotAnimationDuration = const Duration(milliseconds: 300), Curve dotAnimationCurve = Curves.easeInOut, bool autoScroll = false, Duration autoScrollInterval = const Duration(seconds: 3), Duration autoScrollAnimationDuration = const Duration(milliseconds: 300), Curve autoScrollCurve = Curves.easeInOut, ScrollPhysics? scrollPhysics, bool toggleDotsOnTap = false, ValueChanged<int>? onPageChanged, ValueChanged<int>? onCardPressed})
const

Properties

activeDotColor → Color
final
autoScroll → bool
final
autoScrollAnimationDuration → Duration
final
autoScrollCurve → Curve
final
autoScrollInterval → Duration
final
builder → Widget Function(BuildContext context, int index)
Builder callback to build each card.
final
dotAnimationCurve → Curve
final
dotAnimationDuration → Duration
final
dotColor → Color
final
dotSize → double
final
dotSpacing → double
final
hashCode → int
The hash code for this object.
no setterinherited
itemCount → int
Total number of cards.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onCardPressed → ValueChanged<int>?
Called when a card is pressed; provides the tapped card's index.
final
onPageChanged → ValueChanged<int>?
Called when the displayed card changes; provides the new index.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleFactor → double
The scale factor for non‑center cards. For example, 0.8 means side cards are scaled to 80% of full size.
final
scrollPhysics → ScrollPhysics?
final
showDotsIndicator → bool
Whether to display the dots indicator.
final
toggleDotsOnTap → bool
If true, tapping on the carousel toggles the visibility of the dots indicator.
final
viewportFraction → double
The fraction of the viewport that each card occupies.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _MyMiniOnTheRightCardViewerState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited