MyConnectivityWrapper class

Inheritance

Constructors

MyConnectivityWrapper({Key? key, required Widget child, Color overlayColor = Colors.black54, double blurAmount = 5.0, Color messageBackgroundColor = Colors.white, Color messageTextColor = Colors.black87, Color buttonColor = Colors.blue, Color buttonTextColor = Colors.white, String noConnectionMessage = 'No Internet Connection', String buttonText = 'Try Again', double borderRadius = 8.0, EdgeInsets messagePadding = const EdgeInsets.all(24.0), VoidCallback? onButtonPressed, bool showButton = true})
const

Properties

blurAmount → double
final
borderRadius → double
final
buttonColor → Color
final
buttonText → String
final
buttonTextColor → Color
final
child → Widget
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
messageBackgroundColor → Color
final
messagePadding → EdgeInsets
final
messageTextColor → Color
final
noConnectionMessage → String
final
onButtonPressed → VoidCallback?
final
overlayColor → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showButton → bool
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<MyConnectivityWrapper>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited